--- uboot.old/common/cmd_bootm.c	2009-08-10 22:12:45.000000000 +0530
+++ uboot/common/cmd_bootm.c	2009-08-10 22:06:57.000000000 +0530
@@ -129,6 +129,8 @@
 #ifdef CONFIG_SILENT_CONSOLE
 static void fixup_silent_linux (void);
 #endif
+static void fixup_verbose (void);
+static void set_auto_update_battery_fw(void);
 #ifdef CONFIG_PASS_PLATFORM_ID
 static void set_platform_id(void);
 #endif
@@ -167,8 +169,16 @@
 	char	*name, *s;
 	int	(*appl)(int, char *[]);
 	image_header_t *hdr = &header;
-
+	unsigned short verbose_check=0;
+	char *verbose;
 	s = getenv ("verify");
+	verbose = getenv ("verbose");
+	
+	if(verbose!=NULL)
+			verbose_check = ((strncmp(verbose,"false",5)==0)||(strncmp(verbose,"FALSE",5)==0)||(strncmp(verbose,"0",1)==0))? 1 : 0;
+	else
+			verbose_check = 1;
+
 	verify = (s && (*s == 'n')) ? 0 : 1;
 
 	if (argc < 2) {
@@ -178,7 +188,9 @@
 	}
 
 	SHOW_BOOT_PROGRESS (1);
-	printf ("## Booting image at %08lx ...\n", addr);
+	
+	if(verbose_check!=1)
+			printf ("## Booting image at %08lx ...\n", addr);
 
 	/* Copy header so we can blank CRC field for re-calculation */
 #ifdef CONFIG_HAS_DATAFLASH
@@ -205,7 +217,8 @@
 		} else
 #endif	/* __I386__ */
 	    {
-		puts ("Bad Magic Number\n");
+				if(verbose_check!=1)
+						puts ("Bad Magic Number\n");
 		SHOW_BOOT_PROGRESS (-1);
 		return 1;
 	    }
@@ -219,7 +232,8 @@
 	hdr->ih_hcrc = 0;
 
 	if (crc32 (0, (uchar *)data, len) != checksum) {
-		puts ("Bad Header Checksum\n");
+			if(verbose_check!=1)
+					puts ("Bad Header Checksum\n");
 		SHOW_BOOT_PROGRESS (-2);
 		return 1;
 	}
@@ -248,12 +262,15 @@
 	len  = ntohl(hdr->ih_size);
 
 	if (verify) {
-		puts ("   Verifying Checksum ... ");
+			if(verbose_check!=1)
+					puts ("   Verifying Checksum ... ");
 		if (crc32 (0, (uchar *)data, len) != ntohl(hdr->ih_dcrc)) {
-			printf ("Bad Data CRC\n");
+				if(verbose_check!=1)
+						printf ("Bad Data CRC\n");
 			SHOW_BOOT_PROGRESS (-3);
 			return 1;
 		}
+		if(verbose_check!=1)
 		puts ("OK\n");
 		console_init_f ();
 	}
@@ -285,7 +302,8 @@
 # error Unknown CPU type
 #endif
 	{
-		printf ("Unsupported Architecture 0x%x\n", hdr->ih_arch);
+			if(verbose_check!=1)
+					printf ("Unsupported Architecture 0x%x\n", hdr->ih_arch);
 		SHOW_BOOT_PROGRESS (-4);
 		return 1;
 	}
@@ -310,7 +328,9 @@
 		for (i=1; len_ptr[i]; ++i)
 			data += 4;
 		break;
-	default: printf ("Wrong Image Type for %s command\n", cmdtp->name);
+	default:
+		if(verbose_check!=1) 
+				printf ("Wrong Image Type for %s command\n", cmdtp->name);
 		SHOW_BOOT_PROGRESS (-5);
 		return 1;
 	}
@@ -344,8 +364,8 @@
 			size_t l = len;
 			void *to = (void *)ntohl(hdr->ih_load);
 			void *from = (void *)data;
-
-			printf ("   Loading %s ... ", name);
+			if(verbose_check!=1)
+					printf ("   Loading %s ... ", name);
 
 			while (l > 0) {
 				size_t tail = (l > CHUNKSZ) ? CHUNKSZ : l;
@@ -361,17 +381,20 @@
 		}
 		break;
 	case IH_COMP_GZIP:
-		printf ("   Uncompressing %s ... ", name);
+		if(verbose_check!=1)
+				printf ("   Uncompressing %s ... ", name);
 		if (gunzip ((void *)ntohl(hdr->ih_load), unc_len,
 			    (uchar *)data, &len) != 0) {
-			puts ("GUNZIP ERROR - must RESET board to recover\n");
+				if(verbose_check!=1)
+						puts ("GUNZIP ERROR - must RESET board to recover\n");
 			SHOW_BOOT_PROGRESS (-6);
 			do_reset (cmdtp, flag, argc, argv);
 		}
 		break;
 #ifdef CONFIG_BZIP2
 	case IH_COMP_BZIP2:
-		printf ("   Uncompressing %s ... ", name);
+		if(verbose_check!=1)
+				printf ("   Uncompressing %s ... ", name);
 		/*
 		 * If we've got less than 4 MB of malloc() space,
 		 * use slower decompression algorithm which requires
@@ -381,7 +404,8 @@
 						&unc_len, (char *)data, len,
 						CFG_MALLOC_LEN < (4096 * 1024), 0);
 		if (i != BZ_OK) {
-			printf ("BUNZIP2 ERROR %d - must RESET board to recover\n", i);
+				if(verbose_check!=1)
+						printf ("BUNZIP2 ERROR %d - must RESET board to recover\n", i);
 			SHOW_BOOT_PROGRESS (-6);
 			udelay(100000);
 			do_reset (cmdtp, flag, argc, argv);
@@ -391,11 +415,13 @@
 	default:
 		if (iflag)
 			enable_interrupts();
-		printf ("Unimplemented compression type %d\n", hdr->ih_comp);
+		if(verbose_check!=1)
+				printf ("Unimplemented compression type %d\n", hdr->ih_comp);
 		SHOW_BOOT_PROGRESS (-7);
 		return 1;
 	}
-	puts ("OK\n");
+	if(verbose_check!=1)
+			puts ("OK\n");
 	SHOW_BOOT_PROGRESS (7);
 
 	switch (hdr->ih_type) {
@@ -422,7 +448,8 @@
 	default:
 		if (iflag)
 			enable_interrupts();
-		printf ("Can't boot image type %d\n", hdr->ih_type);
+		if(verbose_check!=1)
+				printf ("Can't boot image type %d\n", hdr->ih_type);
 		SHOW_BOOT_PROGRESS (-8);
 		return 1;
 	}
@@ -434,6 +461,11 @@
 #ifdef CONFIG_SILENT_CONSOLE
 	    fixup_silent_linux();
 #endif
+		fixup_verbose(); 
+ #ifdef CONFIG_PASS_PLATFORM_ID
+ 	    set_platform_id ();
+ #endif
+		set_auto_update_battery_fw();
 #ifdef CONFIG_PASS_PLATFORM_ID
 	    set_cmdline();
 #endif
@@ -478,7 +507,8 @@
 
 	SHOW_BOOT_PROGRESS (-9);
 #ifdef DEBUG
-	puts ("\n## Control returned to monitor - resetting...\n");
+	if(verbose_check!=1)
+			puts ("\n## Control returned to monitor - resetting...\n");
 	do_reset (cmdtp, flag, argc, argv);
 #endif
 	return 1;
@@ -499,6 +529,93 @@
 #endif
 );
 
+/*
+  * read the auto update battery fw env. variable
+  * and append it with the bootargs param before the platform id
+  */
+static void
+set_auto_update_battery_fw()
+{
+
+	char buf[2048] = {0};
+	char *start, *end;
+	char tempBatteryState [64];
+	char *cmdline;
+	char *BatteryAutoUpdate;
+	int len = 0;
+
+	/* check If  BATTERY_AUTO_UPDATE_ENABLED variable set :  store its value from uboot env or set it to default as "false"*/
+	BatteryAutoUpdate = getenv("BATTERY_AUTO_UPDATE_ENABLED");
+
+	if(BatteryAutoUpdate == NULL || (strnicmp(BatteryAutoUpdate,"true",4) != 0 && strnicmp(BatteryAutoUpdate,"false",5) != 0))
+	{
+		setenv("BATTERY_AUTO_UPDATE_ENABLED","false");
+		debug("Setting the Env Variable-BATTERY_AUTO_UPDATE_ENABLED as False\n");
+		saveenv();
+
+		/*getenv called again here because pointer value might be changed or not valid after setenv and saveenv above*/
+               BatteryAutoUpdate = getenv("BATTERY_AUTO_UPDATE_ENABLED");
+        }
+       if ( (cmdline = getenv("bootargs")) == NULL )
+                return ;
+
+	debug(" BATTERY_AUTO_UPDATE_ENABLED in uboot param is  =  %s\n", BatteryAutoUpdate);
+	debug(" Before Appending BATTERY_AUTO_UPDATE_ENABLED variable to cmdline : %s\n", cmdline);
+
+
+  /*check if BATTERY_AUTO_UPDATE_ENABLED is already present in cmdline ,if present search for that string in cmdline and change its value */
+	if ((start = strstr (cmdline, "BATTERY_AUTO_UPDATE_ENABLED=")) != NULL)
+	{
+		end = strchr (start, ' ');
+		if ( NULL == end )
+		end = cmdline + strlen(cmdline);
+
+		debug ( "start %s \n, end %s\n",start,end);
+
+		/*copied the prefix before platform id*/
+		strncpy (buf, cmdline, (start - cmdline + 28));
+		buf [ start - cmdline + 28] =0;
+
+		debug ( "INT 1 buf %s \n", buf );
+
+		len = end - start - 28;
+
+		debug ( "len of BATTERY_AUTO_UPDATE_ENABLED %d\n", len);
+		debug ( "tempBatteryState   %s \n",cmdline+(start - cmdline + 28) );
+
+		if ( end-start > 64 )
+			{len = 64;}
+		strncpy ( tempBatteryState, cmdline + (start - cmdline + 28), len);
+		tempBatteryState[len] = 0;
+
+		debug ( " tempBatteryState = %s , BatteryAutoUpdate = %s\n", tempBatteryState, BatteryAutoUpdate);
+
+		if ( 0 == strcmp ( tempBatteryState, BatteryAutoUpdate ))
+		{
+			debug ( " matching tempBatteryState  = %s , BatteryAutoUpdate =  %s \n",tempBatteryState,BatteryAutoUpdate);
+			return ;
+		}
+
+		strcat ( buf, BatteryAutoUpdate );
+		debug ( "INT 2 buf %s \n", buf );
+
+		strcat (buf, cmdline + (end - cmdline ) );
+		debug ( "after appending %s\n", buf);
+
+	}
+	else
+	{
+		strcpy(buf, cmdline);
+		debug("command line already exists.\n");
+		strcat(buf, " BATTERY_AUTO_UPDATE_ENABLED=");
+		strcat(buf, BatteryAutoUpdate);
+	}
+
+	setenv("bootargs", buf);
+	debug(" After Appending BATTERY_AUTO_UPDATE_ENABLED variable to cmdline is: %s\n", buf);
+	return ;
+
+}
 
 #ifdef CONFIG_PASS_PLATFORM_ID		
 
@@ -609,6 +674,50 @@
 }
 #endif /* CONFIG_SILENT_CONSOLE */
 
+static void fixup_verbose (void)
+{
+	char buf[256],*start, *end;
+	char *cmdline = getenv ("bootargs");
+	char *verbose = getenv ("verbose");
+	char *verbose_default="false";
+	if(verbose==NULL)
+		verbose=verbose_default;
+
+	if(verbose!=NULL)
+	{
+			if((strcmp(verbose,"false")==0) || (strcmp(verbose,"FALSE")==0) ||
+							(strcmp(verbose,"0")==0))
+			{
+					//printf("Before Verbose Settings:%s\n", cmdline);
+					if(cmdline)
+					{
+							if((start=strstr(cmdline,"console=")) != NULL)
+							{
+									strncpy(buf,cmdline,(start-cmdline));
+									//printf("\n\nAfter Copying Buffer:%s\n", buf);
+									end = strchr(start,' ');
+									if(end)
+											strcat(buf,end+1);
+
+									strcat(buf," console=/dev/null");
+									//printf("\n\nCheck point 2:%s\n", buf);
+							}			
+							else
+							{
+									strcpy(buf, cmdline);
+									strcat(buf, " console=/dev/null");
+							}
+					}
+					else
+					{
+							strcpy(buf,"console=/dev/null");
+					}
+					setenv ("bootargs", buf);
+					//printf("After Verbose Settings:%s\n", buf);
+			}
+	}
+}
+
 #ifdef CONFIG_PPC
 static void  __attribute__((noinline))
 do_bootm_linux (cmd_tbl_t *cmdtp, int flag,
@@ -1413,31 +1522,44 @@
 	time_t timestamp = (time_t)ntohl(hdr->ih_time);
 	struct rtc_time tm;
 #endif
-
-	printf ("   Image Name:   %.*s\n", IH_NMLEN, hdr->ih_name);
+	char *verbose=getenv("verbose");
+	unsigned short verbose_check=0;
+	
+	if(verbose!=NULL)
+			verbose_check=((strncmp(verbose,"false",5)==0)||(strncmp(verbose,"FALSE",5)==0)||(strncmp(verbose,"0",1)==0))? 1: 0;
+	else
+			verbose_check=1;
+	//printf("verbose_check to verify:%d\n",verbose_check);
+	if(!verbose_check)
+			printf ("   Image Name:   %.*s\n", IH_NMLEN, hdr->ih_name);
 #if (CONFIG_COMMANDS & CFG_CMD_DATE) || defined(CONFIG_TIMESTAMP)
 	to_tm (timestamp, &tm);
-	printf ("   Created:      %4d-%02d-%02d  %2d:%02d:%02d UTC\n",
-		tm.tm_year, tm.tm_mon, tm.tm_mday,
-		tm.tm_hour, tm.tm_min, tm.tm_sec);
+	if(verbose_check!=1)
+			printf ("   Created:      %4d-%02d-%02d  %2d:%02d:%02d UTC\n",
+				tm.tm_year, tm.tm_mon, tm.tm_mday,
+				tm.tm_hour, tm.tm_min, tm.tm_sec);
 #endif	/* CFG_CMD_DATE, CONFIG_TIMESTAMP */
-	puts ("   Image Type:   "); print_type(hdr);
-	printf ("\n   Data Size:    %d Bytes = ", ntohl(hdr->ih_size));
-	print_size (ntohl(hdr->ih_size), "\n");
-	printf ("   Load Address: %08x\n"
-		"   Entry Point:  %08x\n",
-		 ntohl(hdr->ih_load), ntohl(hdr->ih_ep));
-
+	if(verbose_check!=1)
+	{
+			puts ("   Image Type:   "); print_type(hdr);
+			printf ("\n   Data Size:    %d Bytes = ", ntohl(hdr->ih_size));
+			print_size (ntohl(hdr->ih_size), "\n");
+			printf ("   Load Address: %08x\n"
+					"   Entry Point:  %08x\n",
+						ntohl(hdr->ih_load), ntohl(hdr->ih_ep));
+	}
 	if (hdr->ih_type == IH_TYPE_MULTI) {
 		int i;
 		ulong len;
 		ulong *len_ptr = (ulong *)((ulong)hdr + sizeof(image_header_t));
-
-		puts ("   Contents:\n");
+		if(verbose_check!=1)
+				puts ("   Contents:\n");
 		for (i=0; (len = ntohl(*len_ptr)); ++i, ++len_ptr) {
-			printf ("   Image %d: %8ld Bytes = ", i, len);
-			print_size (len, "\n");
-		}
+				if(verbose_check!=1){
+						printf ("   Image %d: %8ld Bytes = ", i, len);
+						print_size (len, "\n");
+				}
+		}		
 	}
 }
 
